HasTokenizeLiteral class abstract

Contract for models that tokenize raw input segments.

Inheritance
Implementers

Constructors

HasTokenizeLiteral({required String name})
Creates a literal-tokenizing model contract.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether this model matches no content.
no setterinherited
name String
Human-readable token name.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tokenize(List<Input> input) → (List<Token>, List<Input>)
Produces tokens and remaining unmatched segments.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited